@@ -1,33 +1,13 @@
-from lxml import etree
+
 import logging
 import requests
-from typing import Dict, List, Tuple, Optional, Callable, Set, AnyStr, Literal
+from typing import Dict, List, Tuple, Optional, AnyStr, Literal, Set
 import os
 import re
 import hashlib
-
-
-def check_error(fn: Callable) -> Callable:
-    """Prevents operation if the record is containing an error
-
-    :param fn: Method that should not to be executed in case of error
-
-    :return: Wrapper function of the decorator
-    """
-
-    def wrapper(*args, **kwargs):
-        """Wrapper function
-        """
-        rec = args[0]
-        if rec.error is False and rec.data is not None:
-            rec = fn(*args, **kwargs)
-        else:
-            logging.error(f'{repr(rec)}: due to error to the record, process "{fn.__name__}" skipped.')
-        return rec
-
-    wrapper.__doc__ = fn.__doc__
-
-    return wrapper
+from .common import check_error
+import shutil
+from lxml import etree
 
 
 class SruRequest:
@@ -209,6 +189,16 @@ class SruClient:
         if os.path.isdir('./requests') is False:
             os.mkdir('./requests')
 
+    @classmethod
+    def clean_old_requests(cls) -> None:
+        """Delete and recreate the requests folder and reset the requests and records attributes"""
+        if os.path.isdir('./requests') is True:
+            shutil.rmtree('./requests')
+        os.mkdir('./requests')
+
+        cls.requests = dict()
+        cls.records = dict()
+
     @classmethod
     def set_base_url(cls, base_url: str) -> None:
         """Set the base url of the SRU client
@@ -340,7 +330,7 @@ class SruRecord:
 
         if slsp_only is True:
             # return only SLSP related system ids
-            prefixes = '|'.join(['RERO', 'IDSBB', 'IDSLU', 'IDSSG', 'NEBIS', 'SBT', 'ALEX', 'ABN', 'swissbib'])
+            prefixes = '|'.join(['RERO', 'IDSBB', 'IDSLU', 'IDSSG', 'NEBIS', 'SBT', 'ALEX', 'ABN', 'swissbib', 'HAN'])
             other_sys_ids = {sys_num for sys_num in other_sys_ids
                              if re.match(r'^\((?:{})\).+'.format(prefixes), sys_num)}
         return other_sys_ids
