@@ -3,6 +3,8 @@ import pandas as pd
 import numpy as np
 from typing import List, Optional
 import logging
+from lxml import etree
+import re
 
 
 def analyse_records(mms_ids: List[str], filepath: Optional[str] = None) -> pd.DataFrame:
@@ -184,3 +186,41 @@ def check_removable_records(mms_ids: List[str], filepath: Optional[str] = None)
         df.to_excel(filepath)
 
     return df
+
+
+def roman_to_int(roman_number: str) -> int:
+    """Transform roman number to integer
+    :param roman_number: roman number
+    :return: int value of the number
+    """
+    roman = {'I': 1, 'V': 5, 'X': 10, 'L': 50, 'C': 100, 'D': 500, 'M': 1000, 'IV': 4, 'IX': 9, 'XL': 40, 'XC': 90,
+             'CD': 400, 'CM': 900}
+    i = 0
+    num = 0
+
+    # Only capitals
+    roman_number = roman_number.upper()
+
+    while i < len(roman_number):
+        # Check if a digramme like IV is in the number
+        if i + 1 < len(roman_number) and roman_number[i:i + 2] in roman:
+            num += roman[roman_number[i:i + 2]]
+            i += 2
+
+        elif roman_number[i] in roman:
+            num += roman[roman_number[i]]
+            i += 1
+
+    return num
+
+
+def remove_ns(data: etree.Element) -> etree.Element:
+    """Remove namespace from XML data
+    :param data: `etree.Element` object with xml data
+    :return: `etree.Element` without namespace information
+    :rtype:
+    """
+    temp_data = etree.tostring(data).decode()
+    temp_data = re.sub(r'\s?xmlns="[^"]+"', '', temp_data).encode()
+    return etree.fromstring(temp_data)
+
